<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class User extends Model 
{

    protected $table = 'users';
    public $timestamps = true;

    use SoftDeletes;

    protected $dates = ['deleted_at'];
    protected $fillable = array('role_id', 'first_name', 'last_name', 'email', 'timezone', 'last_activity', 'mobile_number', 'password', 'notification_badge', 'organisation_id', 'profile_image', 'profile_image_thumb', 'remember_token');

    public function organisation()
    {
        return $this->belongsTo('App\Models\Organisation', 'id');
    }

    public function role()
    {
        return $this->hasOne('App\Models\Role', 'id', 'role_id');
    }

    public function work_order()
    {
        return $this->hasMany('App\Models\WorkOrder', 'id');
    }

    public function form()
    {
        return $this->hasMany('App\Models\FormLocation');
    }

    public function location_tracker()
    {
        return $this->hasMany('App\Models\LocationTracker', 'id');
    }

    public function work_order_ann()
    {
        return $this->hasMany('App\Models\WorkOrderAnn', 'id');
    }

    public function notification()
    {
        return $this->hasMany('App\Models\Notifications', 'id');
    }

    public function form_history_track_()
    {
        return $this->hasMany('App\User', 'id');
    }

    public function vehicle_daily()
    {
        return $this->hasMany('App\Models\VehicleDaily', 'id');
    }

    public function vehicle_monthly()
    {
        return $this->hasMany('App\Models\VehicleMonthly', 'id');
    }

    public function driver()
    {
        return $this->hasOne('App\Models\Driver', 'driver_id', 'id');
    }

}